@@ -1,4 +1,4 @@
-from dzauth import OAuth
+from dzopen.dzauth import OAuth
 
 
 class AuthorizePlatformRequest(OAuth):
